@@ -123,18 +123,85 @@ SENSOR_CCT = "CCT"
 SENSOR_PROXIMITY = "Proximity"
 SENSOR_AMBIENT = "Ambient"
 SENSOR_SWITCH = "Switch"
-SENSOR_STATUS_MQTT_COUNT = "status_mqtt_count"
-SENSOR_STATUS_LINK_COUNT = "status_link_count"
-SENSOR_STATUS_SIGNAL = "status_signal"
-SENSOR_STATUS_RSSI = "status_rssi"
-SENSOR_STATUS_RESTART = "status_restart_reason"
 SENSOR_STATUS_IP = "status_ip"
-SENSOR_STATUS_UPTIME = "status_Uptime"
+SENSOR_STATUS_LAST_RESTART_TIME = "last_restart_time"
+SENSOR_STATUS_LINK_COUNT = "status_link_count"
+SENSOR_STATUS_MQTT_COUNT = "status_mqtt_count"
+SENSOR_STATUS_RESTART_REASON = "status_restart_reason"
+SENSOR_STATUS_RSSI = "status_rssi"
+SENSOR_STATUS_SIGNAL = "status_signal"
+SENSOR_STATUS_SSID = "status_ssid"
 
 SENSOR_UNIT_PRESSURE = "PressureUnit"
 SENSOR_UNIT_SPEED = "SpeedUnit"
 SENSOR_UNIT_TEMPERATURE = "TempUnit"
 
+# #### UNITS OF MEASUREMENT ####
+# Power units
+POWER_WATT = "W"
+
+# Voltage units
+VOLT = "V"
+
+# Energy units
+ENERGY_WATT_HOUR = f"{POWER_WATT}h"
+ENERGY_KILO_WATT_HOUR = f"k{ENERGY_WATT_HOUR}"
+
+# Electrical units
+ELECTRICAL_CURRENT_AMPERE = "A"
+ELECTRICAL_VOLT_AMPERE = f"{VOLT}{ELECTRICAL_CURRENT_AMPERE}"
+
+# Temperature units
+TEMP_CELSIUS = "C"
+TEMP_FAHRENHEIT = "F"
+TEMP_KELVIN = "K"
+
+# Time units
+TIME_SECONDS = "s"
+TIME_HOURS = "h"
+
+# Length units
+LENGTH_CENTIMETERS: str = "cm"
+LENGTH_METERS: str = "m"
+LENGTH_KILOMETERS: str = "km"
+
+# Frequency units
+FREQUENCY_HERTZ = "Hz"
+
+# Pressure units
+PRESSURE_HPA: str = "hPa"
+PRESSURE_MMHG: str = "mmHg"
+
+# Volume units
+VOLUME_CUBIC_METERS = f"{LENGTH_METERS}³"
+
+# Mass units
+MASS_KILOGRAMS: str = "kg"
+MASS_MICROGRAMS = "µg"
+
+# Light units
+LIGHT_LUX: str = "lux"
+
+# Percentage units
+PERCENTAGE = "%"
+
+# Concentration units
+CONCENTRATION_MICROGRAMS_PER_CUBIC_METER = f"{MASS_MICROGRAMS}/{VOLUME_CUBIC_METERS}"
+CONCENTRATION_PARTS_PER_MILLION = "ppm"
+CONCENTRATION_PARTS_PER_BILLION = "ppb"
+
+# Speed units
+SPEED_METERS_PER_SECOND = f"{LENGTH_METERS}/{TIME_SECONDS}"
+SPEED_KILOMETERS_PER_HOUR = f"{LENGTH_KILOMETERS}/{TIME_HOURS}"
+SPEED_KNOT = "kn"
+SPEED_MILES_PER_HOUR = "mph"
+SPEED_FEET_PER_SECOND = "ft/s"
+SPEED_YARDS_PER_SECOND = "yd/s"
+
+# Signal_strength units
+SIGNAL_STRENGTH_DECIBELS = "dB"
+SIGNAL_STRENGTH_DECIBELS_MILLIWATT = "dBm"
+
 STATE_OFF = 0
 STATE_ON = 1
 STATE_TOGGLE = 2
